=======================
Barbican for Developers
=======================

If you're new to OpenStack development you should start by reading the
`OpenStack Developer's Guide`_.

.. _`OpenStack Developer's Guide`: https://docs.openstack.org/infra/manual/developers.html

Once you've read the OpenStack guide you'll be ready to set up a local barbican
development environment.

.. toctree::
   :maxdepth: 1

   dev.rst
   devstack.rst

When you're ready to dive deeper in to barbican take a look at:

.. toctree::
   :maxdepth: 1

   contributing.rst
   getting_involved.rst
   architecture.rst
   structure.rst
   dataflow.rst
   dependencies.rst
   database_migrations.rst
   microversions.rst
   plugin/index.rst
   testing.rst
